#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['keruk']

package_data = \
{'': ['*']}

setup(name='keruk',
      version='0.0.2',
      description='Simple Web Downloader',
      author='Aditya Kelvianto Sidharta',
      author_email='aditya.sdrt@gmail.com',
      url='https://github.com/AdityaSidharta/keruk',
      packages=packages,
      package_data=package_data,
     )
